HolE
====

.. currentmodule:: pykeen.models

.. autoclass:: HolE
   :show-inheritance:

   .. rubric:: Attributes Summary

   .. autosummary::

      ~HolE.entity_constrainer_default_kwargs
      ~HolE.hpo_default

   .. rubric:: Attributes Documentation

   .. autoattribute:: entity_constrainer_default_kwargs
   .. autoattribute:: hpo_default
